import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:im_flutter_sdk/im_flutter_sdk.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leoonetconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoocalljunpro/leooitemjunpro/leooconversationlistjunpro.dart';

class LeooConversationListItemJunPro extends StatefulWidget {
  final ConversationList conversation;
  final LeooConversationListItemDelegateJunPro? delegate;

  const LeooConversationListItemJunPro(this.conversation,
      {Key? key, this.delegate})
      : super(key: key);

  @override
  State<StatefulWidget> createState() => _LeooConversationListItemState();
}

class _LeooConversationListItemState
    extends State<LeooConversationListItemJunPro> {
  late ConversationList conversation;
  LeooConversationListItemDelegateJunPro? delegate;

  @override
  void initState() {
    super.initState();
    delegate = widget.delegate;
    conversation = widget.conversation;
  }

  @override
  void didUpdateWidget(LeooConversationListItemJunPro oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (conversation != widget.conversation) {
      conversation = widget.conversation;
    }
  }

  @override
  Widget build(BuildContext context) {
    String hero = '${conversation.info.id}msg_list';
    return InkWell(
      onTap: LeooNavigatorUtilsJunPro.leooDebounceJunPro(
          () => delegate?.didTapConversation(conversation, hero)),
      child: Padding(
        padding: EdgeInsets.all(15.w),
        child: Row(
          children: <Widget>[
            InkWell(
              child: Hero(
                tag: hero,
                transitionOnUserGestures: true,
                child: ClipOval(
                  child: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                    LeooAppConfigJunPro.leooCustomerIdJunPro ==
                            conversation.userInfo.userId
                        ? LeooIconsJunPro.leooAppLogoJunPro
                        : conversation.userInfo.avatarUrl,
                    width: 50.w,
                    height: 50.w,
                    load: LeooIconsJunPro.leooLoadHeadJunPro,
                  ),
                ),
              ),
              onTap: LeooNavigatorUtilsJunPro.leooDebounceJunPro(
                  () => delegate?.didTapHeadConversation(conversation, hero)),
            ),
            SizedBox(width: 10.w),
            Expanded(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                      LeooAppConfigJunPro.leooCustomerIdJunPro ==
                              conversation.userInfo.userId
                          ? S.of(context).mineCustomer
                          : conversation.userInfo.nickName ??
                              LeooNetConfigJunPro.leooAppNameJunPro,
                      style: LeooAppConfigJunPro.leooCustomerIdJunPro ==
                              conversation.userInfo.userId
                          ? LeooTextJunPro.leooGetTextStyleAppJunPro(
                              20, FontWeight.bold)
                          : LeooTextJunPro.leooGetTextStyleJunPro(
                              20, FontWeight.bold),
                      maxLines: 1,
                      overflow: TextOverflow.ellipsis),
                  SizedBox(height: 5.w),
                  Text(
                      LeooCodeUtilsJunPro.leooGetDigestJunPro(
                          conversation.info.latestMessage!.body!, context)!,
                      style: LeooTextJunPro.leooGetTextStyleHintJunPro(16),
                      maxLines: 1,
                      overflow: TextOverflow.ellipsis)
                ],
              ),
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.end,
              children: <Widget>[
                Text(
                    LeooCodeUtilsJunPro.leooGetNewsTimeStrJunPro(
                        context,
                        DateTime.fromMillisecondsSinceEpoch(
                            conversation.info.latestMessage!.localTime)),
                    style: LeooTextJunPro.leooGetTextStyleHintJunPro(14)),
                SizedBox(height: 5.w),
                if (conversation.info.unreadCount != 0)
                  Container(
                    alignment: Alignment.center,
                    padding: EdgeInsets.all(5.w),
                    decoration: ShapeDecoration(
                        color: LeooColorsJunPro.leooApp3JunPro,
                        shape: CircleBorder()),
                    child: Text(
                        conversation.info.unreadCount <= 99
                            ? conversation.info.unreadCount.toString()
                            : '99+',
                        style: LeooTextJunPro.leooGetTextStyleJunPro(12)),
                  ),
              ],
            )
          ],
        ),
      ),
    );
  }
}

abstract class LeooConversationListItemDelegateJunPro {
  ///点击了会话 item
  void didTapConversation(ConversationList item, String hero);

  ///点击了会话 头像
  void didTapHeadConversation(ConversationList item, String hero);
}
